/**
 * @license
 * Copyright (c) 2017 The Polymer Project Authors. All rights reserved.
 * This code may only be used under the BSD style license found at
 * http://polymer.github.io/LICENSE.txt
 * The complete set of authors may be found at
 * http://polymer.github.io/AUTHORS.txt
 * The complete set of contributors may be found at
 * http://polymer.github.io/CONTRIBUTORS.txt
 * Code distributed by Google as part of the polymer project is also
 * subject to an additional IP rights grant found at
 * http://polymer.github.io/PATENTS.txt
 */
import { TemplateResult, AttributePart, TemplateInstance, TemplatePart, Part, Template } from '../lit-html.js';
/**
 *
 * @param result Renders a `TemplateResult` to a container using an
 * `ExtendedTemplateInstance`, which allows templates to set properties and
 * event handlers.
 *
 * Properties are set by default, instead of attributes. Attribute names in
 * lit-html templates preserve case, so properties are case sensitive. If an
 * expression takes up an entire attribute value, then the property is set to
 * that value. If an expression is interpolated with a string or other
 * expressions then the property is set to the string result of the
 * interpolation.
 *
 * To set an attribute instead of a property, append a `$` suffix to the
 * attribute name.
 *
 * Example:
 *
 *     html`<button class$="primary">Buy Now</button>`
 *
 * To set an event handler, prefix the attribute name with `on-` and use a
 * function to return the handler, so that the event handler itself is not
 * called as a template directive.
 *
 * Example:
 *
 *     html`<button on-click=${_=> this.onClickHandler}>Buy Now</button>`
 *
 */
export declare function renderExtendedTo(result: TemplateResult, container: Element | DocumentFragment): void;
export declare class ExtendedTemplateInstance extends TemplateInstance {
    _createPart(templatePart: TemplatePart, node: Node): Part;
    _createInstance(template: Template): ExtendedTemplateInstance;
}
export declare class PropertyPart extends AttributePart {
    setValue(values: any[]): void;
}
export declare class EventPart extends Part {
    element: Element;
    eventName: string;
    private _listener;
    constructor(instance: TemplateInstance, element: Element, eventName: string);
    setValue(value: any): void;
    handleEvent(event: Event): void;
}
